@@ -29,6 +29,10 @@ namespace xt
         using container_type = std::vector<T, EA>;
         using shape_type = std::vector<typename container_type::size_type, SA>;
         using strides_type = shape_type;
+        using backstrides_type = shape_type;
+        using inner_shape_type = shape_type;
+        using inner_strides_type = strides_type;
+        using inner_backstrides_type = backstrides_type;
         using temporary_type = xarray<T, EA, SA>;
     };
 
@@ -49,14 +53,14 @@ namespace xt
      * @tparam T The type of objects stored in the container.
      */
     template <class T, class EA, class SA>
-    class xarray : public xcontainer<xarray<T, EA, SA>>,
+    class xarray : public xstrided_container<xarray<T, EA, SA>>,
                    public xcontainer_semantic<xarray<T, EA, SA>>
     {
 
     public:
 
         using self_type = xarray<T, EA, SA>;
-        using base_type = xcontainer<self_type>;
+        using base_type = xstrided_container<self_type>;
         using semantic_base = xcontainer_semantic<self_type>;
         using container_type = typename base_type::container_type;
         using value_type = typename base_type::value_type;
@@ -117,6 +121,10 @@ namespace xt
         using container_type = C;
         using shape_type = std::vector<typename container_type::size_type, SA>;
         using strides_type = shape_type;
+        using backstrides_type = shape_type;
+        using inner_shape_type = shape_type;
+        using inner_strides_type = strides_type;
+        using inner_backstrides_type = backstrides_type;
         using temporary_type = xarray<typename C::value_type, EA, SA>;
     };
 
@@ -139,14 +147,14 @@ namespace xt
      * @tparam C The container type to adapt.
      */
     template <class C, class EA, class SA>
-    class xarray_adaptor : public xcontainer<xarray_adaptor<C, EA, SA>>,
+    class xarray_adaptor : public xstrided_container<xarray_adaptor<C, EA, SA>>,
                            public xadaptor_semantic<xarray_adaptor<C, EA, SA>>
     {
 
     public:
 
         using self_type = xarray_adaptor<C, EA, SA>;
-        using base_type = xcontainer<self_type>;
+        using base_type = xstrided_container<self_type>;
         using semantic_base = xadaptor_semantic<self_type>;
         using container_type = typename base_type::container_type;
         using shape_type = typename base_type::shape_type;
@@ -466,9 +474,9 @@ namespace xt
     {
         // TODO (performance improvement) : consider moving tmps
         // shape and strides
-        base_type::get_shape() = tmp.shape();
-        base_type::get_strides() = tmp.strides();
-        base_type::get_backstrides() = tmp.backstrides();
+        base_type::shape_impl() = tmp.shape();
+        base_type::strides_impl() = tmp.strides();
+        base_type::backstrides_impl() = tmp.backstrides();
         m_data.resize(tmp.size());
         std::copy(tmp.data().cbegin(), tmp.data().cend(), m_data.begin());
     }
